summaryrefslogtreecommitdiff
path: root/include/apr_md5.h
diff options
context:
space:
mode:
authorwrowe <wrowe@13f79535-47bb-0310-9956-ffa450edef68>2001-05-15 14:15:50 +0000
committerwrowe <wrowe@13f79535-47bb-0310-9956-ffa450edef68>2001-05-15 14:15:50 +0000
commit65e42fb6986c42d96e2e5e8872ab39312230cbec (patch)
treef7888264d22f93d8cd17d0d16c9f99fe9709a0b4 /include/apr_md5.h
parentaa79bd39e09efc8a266bd5a15b02117b871ee235 (diff)
downloadlibapr-65e42fb6986c42d96e2e5e8872ab39312230cbec.tar.gz
Byte counts are apr_size_t, win32 declares a goofy ptrdiff_t that
corresponds to a normal ssize_t. git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@61642 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/apr_md5.h')
-rw-r--r--include/apr_md5.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/apr_md5.h b/include/apr_md5.h
index 4b916ad73..e2de68e90 100644
--- a/include/apr_md5.h
+++ b/include/apr_md5.h
@@ -143,11 +143,11 @@ APR_DECLARE(apr_status_t) apr_md5_set_xlate(apr_md5_ctx_t *context,
* @param context The MD5 content to update.
* @param input next message block to update
* @param inputLen The length of the next message block
* @deffunc apr_status_t apr_md5_update(apr_md5_ctx_t *context, const unsigned char *input, unsigned int inputLen)
*/
APR_DECLARE(apr_status_t) apr_md5_update(apr_md5_ctx_t *context,
const unsigned char *input,
- unsigned int inputLen);
+ apr_size_t inputLen);
/**
* MD5 finalization. Ends an MD5 message-digest operation, writing the
@@ -143,11 +143,11 @@ APR_DECLARE(apr_status_t) apr_md5_set_xlate(apr_md5_ctx_t *context,
* @param input next message block to update
* @param inputLen The length of the next message block
- * @deffunc apr_status_t apr_md5_update(apr_md5_ctx_t *context, const unsigned char *input, unsigned int inputLen)
+ * @deffunc apr_status_t apr_md5_update(apr_md5_ctx_t *context, apr_size_t char *input, unsigned int inputLen)
*/
APR_DECLARE(apr_status_t) apr_md5_update(apr_md5_ctx_t *context,